==> yae-0.1.tar.gz: yae-0.1/mousetext.c <==
/*
 * mousetext.c
 *
 * mousetext fonts data
 */

/*
 *	mouse text fonts bitmap files
 */
#include "mousetext/mtchar40.bmp"
#include "mousetext/mtchar41.bmp"
#include "mousetext/mtchar42.bmp"
#include "mousetext/mtchar43.bmp"
#include "mousetext/mtchar44.bmp"
#include "mousetext/mtchar45.bmp"
#include "mousetext/mtchar46.bmp"
#include "mousetext/mtchar47.bmp"
#include "mousetext/mtchar48.bmp"
#include "mousetext/mtchar49.bmp"
#include "mousetext/mtchar4A.bmp"
#include "mousetext/mtchar4B.bmp"
#include "mousetext/mtchar4C.bmp"
#include "mousetext/mtchar4D.bmp"
#include "mousetext/mtchar4E.bmp"
#include "mousetext/mtchar4F.bmp"
#include "mousetext/mtchar50.bmp"
#include "mousetext/mtchar51.bmp"
#include "mousetext/mtchar52.bmp"
#include "mousetext/mtchar53.bmp"
#include "mousetext/mtchar54.bmp"
#include "mousetext/mtchar55.bmp"
#include "mousetext/mtchar56.bmp"
#include "mousetext/mtchar57.bmp"
#include "mousetext/mtchar58.bmp"
#include "mousetext/mtchar59.bmp"
#include "mousetext/mtchar5A.bmp"
#include "mousetext/mtchar5B.bmp"
#include "mousetext/mtchar5C.bmp"
#include "mousetext/mtchar5D.bmp"
#include "mousetext/mtchar5E.bmp"
#include "mousetext/mtchar5F.bmp"

/*
 *	bitmap index array
 */

#define	MAX_CHAR_BITMAP	0x20
char	*MouseTextFontBitmap[MAX_CHAR_BITMAP] = {
	mtchar40_bits, mtchar41_bits, mtchar42_bits, mtchar43_bits,
	mtchar44_bits, mtchar45_bits, mtchar46_bits, mtchar47_bits,
	mtchar48_bits, mtchar49_bits, mtchar4A_bits, mtchar4B_bits,
	mtchar4C_bits, mtchar4D_bits, mtchar4E_bits, mtchar4F_bits,
	mtchar50_bits, mtchar51_bits, mtchar52_bits, mtchar53_bits,
	mtchar54_bits, mtchar55_bits, mtchar56_bits, mtchar57_bits,
	mtchar58_bits, mtchar59_bits, mtchar5A_bits, mtchar5B_bits,
	mtchar5C_bits, mtchar5D_bits, mtchar5E_bits, mtchar5F_bits,
};

==> yae-0.6.tar.gz: yae-0.6/mousetext.c <==
/*
 * mousetext.c
 *
 * mousetext fonts data
 */

/*
 *	mouse text fonts bitmap files
 */
#include "mousetext/mtchar40.bmp"
#include "mousetext/mtchar41.bmp"
#include "mousetext/mtchar42.bmp"
#include "mousetext/mtchar43.bmp"
#include "mousetext/mtchar44.bmp"
#include "mousetext/mtchar45.bmp"
#include "mousetext/mtchar46.bmp"
#include "mousetext/mtchar47.bmp"
#include "mousetext/mtchar48.bmp"
#include "mousetext/mtchar49.bmp"
#include "mousetext/mtchar4A.bmp"
#include "mousetext/mtchar4B.bmp"
#include "mousetext/mtchar4C.bmp"
#include "mousetext/mtchar4D.bmp"
#include "mousetext/mtchar4E.bmp"
#include "mousetext/mtchar4F.bmp"
#include "mousetext/mtchar50.bmp"
#include "mousetext/mtchar51.bmp"
#include "mousetext/mtchar52.bmp"
#include "mousetext/mtchar53.bmp"
#include "mousetext/mtchar54.bmp"
#include "mousetext/mtchar55.bmp"
#include "mousetext/mtchar56.bmp"
#include "mousetext/mtchar57.bmp"
#include "mousetext/mtchar58.bmp"
#include "mousetext/mtchar59.bmp"
#include "mousetext/mtchar5A.bmp"
#include "mousetext/mtchar5B.bmp"
#include "mousetext/mtchar5C.bmp"
#include "mousetext/mtchar5D.bmp"
#include "mousetext/mtchar5E.bmp"
#include "mousetext/mtchar5F.bmp"

/* running man icon */
#include "mousetext/runningman0.bmp"
#include "mousetext/runningman1.bmp"

/*
 *	bitmap index array
 */

#define	MAX_CHAR_BITMAP	0x20
char	*MouseTextFontBitmap[MAX_CHAR_BITMAP] = {
	mtchar40_bits, mtchar41_bits, mtchar42_bits, mtchar43_bits,
	mtchar44_bits, mtchar45_bits, mtchar46_bits, mtchar47_bits,
	mtchar48_bits, mtchar49_bits, mtchar4A_bits, mtchar4B_bits,
	mtchar4C_bits, mtchar4D_bits, mtchar4E_bits, mtchar4F_bits,
	mtchar50_bits, mtchar51_bits, mtchar52_bits, mtchar53_bits,
	mtchar54_bits, mtchar55_bits, mtchar56_bits, mtchar57_bits,
	mtchar58_bits, mtchar59_bits, mtchar5A_bits, mtchar5B_bits,
	mtchar5C_bits, mtchar5D_bits, mtchar5E_bits, mtchar5F_bits,
};

char	*RunningManFontBitmap[2] = {
	runningman0_bits, runningman1_bits };
